@@ -33,13 +33,13 @@ with requests.Session() as session:
         userInfo = user
 
     def set_tag(property_name, property_value):
-        tags.insert({ property_name: property_value })
+        tags.insert({property_name: property_value})
 
     def info(message, eventTimeRequired = False):
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         print('installed_packages => ', installed_packages)
 
-        eventTime = eventTimeRequired if datetime.now().strftime("%m/%d/%Y, %H:%M:%S") else None
+        eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if eventTimeRequired else None
         print('eventTime => ', eventTime)
 
         sourceFilePath = sys._getframe().f_code
@@ -48,7 +48,7 @@ with requests.Session() as session:
         methodName = sys._getframe(1).f_code.co_name
         print('methodName => ', methodName)
 
-        version = pkg_resources.require('alertnow-phyton')[0].version
+        version = pkg_resources.get_distribution('alertnow-python')[0].version
         print('version => ', version)
         detail = [
             PayloadDetail(
